Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(666)

Unified Diff: third_party/WebKit/Source/core/layout/LayoutObject.h

Issue 1755853002: Remove old paint offset caching code (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Rebase Created 4 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/core/layout/LayoutObject.h
diff --git a/third_party/WebKit/Source/core/layout/LayoutObject.h b/third_party/WebKit/Source/core/layout/LayoutObject.h
index fdce251f83ea92c68b334d2cd53f37c98a64d477..6f36fa3e9d7b093d40c4e2f3f5e3129a7f43e55c 100644
--- a/third_party/WebKit/Source/core/layout/LayoutObject.h
+++ b/third_party/WebKit/Source/core/layout/LayoutObject.h
@@ -1291,23 +1291,23 @@ public:
// The previous position of the top-left corner of the object in its previous paint backing.
const LayoutPoint& previousPositionFromPaintInvalidationBacking() const
{
- ASSERT(!RuntimeEnabledFeatures::slimmingPaintOffsetCachingEnabled());
+ ASSERT(!RuntimeEnabledFeatures::slimmingPaintInvalidationEnabled());
return m_previousPositionFromPaintInvalidationBacking;
}
void setPreviousPositionFromPaintInvalidationBacking(const LayoutPoint& positionFromPaintInvalidationBacking)
{
- ASSERT(!RuntimeEnabledFeatures::slimmingPaintOffsetCachingEnabled());
+ ASSERT(!RuntimeEnabledFeatures::slimmingPaintInvalidationEnabled());
m_previousPositionFromPaintInvalidationBacking = positionFromPaintInvalidationBacking;
}
bool paintOffsetChanged(const LayoutPoint& newPaintOffset) const
{
- ASSERT(RuntimeEnabledFeatures::slimmingPaintOffsetCachingEnabled());
+ ASSERT(RuntimeEnabledFeatures::slimmingPaintInvalidationEnabled());
return m_previousPositionFromPaintInvalidationBacking != uninitializedPaintOffset() && m_previousPositionFromPaintInvalidationBacking != newPaintOffset;
}
void setPreviousPaintOffset(const LayoutPoint& paintOffset)
{
- ASSERT(RuntimeEnabledFeatures::slimmingPaintOffsetCachingEnabled());
+ ASSERT(RuntimeEnabledFeatures::slimmingPaintInvalidationEnabled());
m_previousPositionFromPaintInvalidationBacking = paintOffset;
}
@@ -1908,8 +1908,8 @@ private:
// This stores the position in the paint invalidation backing's coordinate.
// It is used to detect layoutObject shifts that forces a full invalidation.
// This point does *not* account for composited scrolling. See adjustInvalidationRectForCompositedScrolling().
// For slimmingPaintOffsetCaching, this stores the previous paint offset.
// TODO(wangxianzhu): Rename this to m_previousPaintOffset when we enable slimmingPaintOffsetCaching.
LayoutPoint m_previousPositionFromPaintInvalidationBacking;
};
« no previous file with comments | « third_party/WebKit/Source/core/layout/LayoutBox.cpp ('k') | third_party/WebKit/Source/core/layout/LayoutObject.cpp » ('j') | no next file with comments »
@@ -1908,8 +1908,8 @@ private:
// It is used to detect layoutObject shifts that forces a full invalidation.
// This point does *not* account for composited scrolling. See adjustInvalidationRectForCompositedScrolling().
- // For slimmingPaintOffsetCaching, this stores the previous paint offset.
- // TODO(wangxianzhu): Rename this to m_previousPaintOffset when we enable slimmingPaintOffsetCaching.
+ // For slimmingPaintInvalidation, this stores the previous paint offset.
+ // TODO(wangxianzhu): Rename this to m_previousPaintOffset when we enable slimmingPaintInvalidation.
LayoutPoint m_previousPositionFromPaintInvalidationBacking;
};

Powered by Google App Engine
This is Rietveld 408576698